%DETECCIÓN DE PERIODICIDAD.
%function [ptch,oldlagcount,veryoldlagcount]=perdec(Nj,oldlagcount,veryoldlagcount)
%Entradas:
%Nj:términos de autocorrelación de las cuatro tramas anteriores.
%oldlagcount:contador para variables Nj.
%veryoldlagcount:valor anterior del contador para variables Nj.
%Salidas:
%ptch:variable que indica si hay periodicidad o no.
%oldlagcount:contador para variables Nj.
%veryoldlagcount:valor anterior del contador para variables Nj.
function [ptch,oldlagcount,veryoldlagcount]=perdec(Nj,oldlagcount,veryoldlagcount)
lthresh=2;
nthresh=4;
if(oldlagcount+veryoldlagcount>=nthresh)
   ptch=1;
else
   ptch=0;
end
lagcount=0;
for i=1:4
   smallag=mod(max(Nj(i+1),Nj(i)),min(Nj(i+1),Nj(i)));
   if(min(smallag,min(Nj(i+1),(Nj(i)-smallag)))<lthresh)
      lagcount=lagcount+1;
   end
   veryoldlagcount=oldlagcount;
   oldlagcount=lagcount;
end
